##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/edge_stacks/operation/EdgeStackDelete)Delete an EdgeStack
**Access policy** : administrator
##### Authorizations:
_ApiKeyAuth_ _jwt_
##### path Parameters
idrequired |  integer EdgeStack Id
---|---
### Responses
**204**
No Content
**400**
Bad Request
**500**
Internal Server Error
**503**
Edge compute features are disabled
delete/edge_stacks/{id}
https://api-docs.portainer.io/api/edge_stacks/{id}
